<?php

declare(strict_types=1);

namespace Drupal\sobki_ui_suite\Plugin\UiStyles\Source;

use Drupal\Core\Render\RendererInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\ui_styles\Attribute\Source;
use Drupal\ui_styles\Definition\StyleDefinition;
use Drupal\ui_styles\Source\SourcePluginBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Source Sobki Select widget.
 *
 * Used when there are multiple options.
 * When on the front theme, default select is used.
 */
#[Source(
  id: 'sobki_select',
  label: new TranslatableMarkup('Sobki Select'),
  weight: SobkiSelect::WEIGHT,
)]
class SobkiSelect extends SourcePluginBase {

  use StringTranslationTrait;

  public const WEIGHT = 5;

  /**
   * The renderer service.
   *
   * @var \Drupal\Core\Render\RendererInterface
   */
  protected RendererInterface $renderer;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    $instance = parent::create($container, $configuration, $plugin_id, $plugin_definition);
    $instance->renderer = $container->get('renderer');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function getWidgetForm(StyleDefinition $definition, string $selected = ''): array {
    return [
      '#type' => 'select',
      '#title' => $definition->getLabel(),
      '#options' => $definition->getOptionsAsOptions(),
      '#empty_option' => $definition->getEmptyOption(),
      '#default_value' => $selected,
      '#weight' => $definition->getWeight(),
    ];
  }

}
